==> haskell-persistent-2.7.0-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.7.0
id: persistent-2.7.0-E3bGu8baThaIC1FPuHlNCa
key: persistent-2.7.0-E3bGu8baThaIC1FPuHlNCa
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
abi: ad999a81b72dac45d766c29273dd4ba8
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-2.7.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/persistent-2.7.0
hs-libraries: HSpersistent-2.7.0-E3bGu8baThaIC1FPuHlNCa
depends:
    base-4.10.0.0 bytestring-0.10.8.2 transformers-0.5.2.0 time-1.8.0.2
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz containers-0.5.10.2
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj
    lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ
    resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG
    path-pieces-0.2.1-3aB5yqkjw3g6TYHBL5lTHL
    http-api-data-0.3.7.1-F355QzB7S4d4QWa0UqTiBa
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i
    transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    template-haskell-2.12.0.0 blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL
    silently-1.2.5-4d48ibUelDmLXErYHoAYYi
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=8abc34d96a58625e2975ccc02aacab97
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=6bf0cea2ccec20058d527d53a4f54166
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=98ab8c145be258d01b7a6333e00858ed
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=dfad8947f11740596f17fadd714d5078
             lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ=cf58c71914eac1aaf26174fb0607ced0
             resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG=7045beb6d85d0b408839717a807445b4
             path-pieces-0.2.1-3aB5yqkjw3g6TYHBL5lTHL=0254664bbbb77d5f938c727f55b2fb05
             http-api-data-0.3.7.1-F355QzB7S4d4QWa0UqTiBa=c81729baf2f025ee863e24a213d464cd
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=5e6b7bed78b23d60beb18bffc251a955
             monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i=ae71fa24f4a725ec3254a0c142a3f528
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=488e16d42785d73d2eee418d7735d08a
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=3f1f6920f093e2e6ae14fb0bb49a0b10
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=754c9623208b731856696d360a56d5ab
             template-haskell-2.12.0.0=f12600dbe1b363b1dcebe6addb7b269e
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=7d7fdc10b11e72a088b6791e8c321cca
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=271c22b9b241ac1554c7c5cfd744d37e
             silently-1.2.5-4d48ibUelDmLXErYHoAYYi=a6481e475e5c71c79dc52da39b84d53d
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=dff2eda61fc7cfa040a2eb3f0192c69a
             fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7=16c219a41af91cafefb6128e6509601b
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=4e1885ea3bd9d96a68a990bad22946fe
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=6c301deca00e1028f6b7aaf9783563bf
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.7.0-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.7.0
id: persistent-2.7.0-I8wmVXOMY0i6N2WQ58UsGf
key: persistent-2.7.0-I8wmVXOMY0i6N2WQ58UsGf
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
abi: c53e1f43762e773eded8a5cc34ce4c32
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-2.7.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/persistent-2.7.0
hs-libraries: HSpersistent-2.7.0-I8wmVXOMY0i6N2WQ58UsGf
depends:
    base-4.10.0.0 bytestring-0.10.8.2 transformers-0.5.2.0 time-1.8.0.2
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz containers-0.5.10.2
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj
    lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ
    resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG
    path-pieces-0.2.1-3aB5yqkjw3g6TYHBL5lTHL
    http-api-data-0.3.7.1-F355QzB7S4d4QWa0UqTiBa
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i
    transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    template-haskell-2.12.0.0 blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL
    silently-1.2.5-4d48ibUelDmLXErYHoAYYi
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=8abc34d96a58625e2975ccc02aacab97
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=6bf0cea2ccec20058d527d53a4f54166
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=98ab8c145be258d01b7a6333e00858ed
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=dfad8947f11740596f17fadd714d5078
             lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ=cf58c71914eac1aaf26174fb0607ced0
             resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG=7045beb6d85d0b408839717a807445b4
             path-pieces-0.2.1-3aB5yqkjw3g6TYHBL5lTHL=0254664bbbb77d5f938c727f55b2fb05
             http-api-data-0.3.7.1-F355QzB7S4d4QWa0UqTiBa=c81729baf2f025ee863e24a213d464cd
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=66a2d17fbbc7a6e96ce7fb88add84f33
             monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i=ae71fa24f4a725ec3254a0c142a3f528
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=488e16d42785d73d2eee418d7735d08a
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=3f1f6920f093e2e6ae14fb0bb49a0b10
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=754c9623208b731856696d360a56d5ab
             template-haskell-2.12.0.0=f12600dbe1b363b1dcebe6addb7b269e
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=7d7fdc10b11e72a088b6791e8c321cca
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=271c22b9b241ac1554c7c5cfd744d37e
             silently-1.2.5-4d48ibUelDmLXErYHoAYYi=a6481e475e5c71c79dc52da39b84d53d
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=dff2eda61fc7cfa040a2eb3f0192c69a
             fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7=16c219a41af91cafefb6128e6509601b
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=4e1885ea3bd9d96a68a990bad22946fe
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=6c301deca00e1028f6b7aaf9783563bf
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
